import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.Choice;
import javax.microedition.lcdui.ChoiceGroup;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;
import javax.microedition.lcdui.TextField;

/**
   Demonstrates the use of Alert objects. 
*/
public class AlertDemo extends Form 
  implements CommandListener
{
  private Command go = 
    new Command("Go", Command.SCREEN, 1);

  private Command back = 
    new Command("Back", Command.BACK, 1);

  private ChoiceGroup type;
  private TextField tPref;

  private String [] elements =
  {
    "Alarm",
    "Confirmation",
    "Error",
    "Information",
    "Warning"
  };
  
  // Need this so other screens can refer to the instance
  // of this class.
  private static Displayable instance; 

  /**
     Constructor.
  */
  public AlertDemo()
  {
    super("Build alert");

    type = buildAlertTypeSelection();
    tPref = buildTimeoutPrefPrompt();
    append(type);
    append(tPref);

    addCommand(go);
    addCommand(back);
    setCommandListener(this);

    instance = this;
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  static Displayable getInstance()
  {
    return instance;
  }

  private ChoiceGroup buildAlertTypeSelection()
  {
    // Doesn't work if this is Choice.IMPLICIT.
    // See Choice documentation.  IMPLICIT is valid 
    // for List only.
    return new ChoiceGroup("Alert Type", 
                           Choice.EXCLUSIVE, 
                           elements, 
                           null);
  }

  private TextField buildTimeoutPrefPrompt()
  {
    String MAX_TIMEOUT_VALUE = "5";
    int MAX_SIZE = 8; 

    return new TextField("Timeout (sec.)", 
			 MAX_TIMEOUT_VALUE, 
			 MAX_SIZE, 
			 TextField.NUMERIC);
  }

  public void commandAction(Command c, Displayable d)
  {
    UIComponentDemo demo = UIComponentDemo.getInstance();
    Display display = Display.getDisplay(demo);
    int timeSec; 
    int timeMillis;

    if (c == go)
      {
	// Alerts don't accept application defined 
	// Commands.  
	String title = elements[type.getSelectedIndex()];
	Alert alert = new Alert(title);
	alert.setString("A '" + title + "' alert");
	timeSec = Integer.parseInt(tPref.getString());
	timeMillis = timeSec * 1000;
	if (timeMillis <= 0)
	  {
	    timeMillis = Alert.FOREVER;
	  }
	alert.setTimeout(timeMillis);
	display.setCurrent(alert, AlertDemo.getInstance());
      }
    if (c == back)
      {
	UIComponentDemo.getInstance().display();
      }
  }

}

