import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Graphics;

/**
   Defines a subclass of Canvas that is displayed by the
   CanvasDemo1 MIDlet.  This Canvas has a single "Exit"
   command so the user can terminate the demo.

   @see CanvasDemo1
*/
public class Canvas1 extends Canvas 
  implements CommandListener
{
  private Command exit = 
    new Command("Exit", Command.EXIT, 1);

  /**
     No-arg constructor.  
  */
  public Canvas1()
  {
    // Note the call to super(), which is the Canvas
    // no-arg constructor!  This is very important.
    // Without a call to super() your Canvas instances
    // will not be able to behave like a real Canvas.
    // They won't display properly, they won't paint
    // properly, and they won't be able to process events.
    super();

    addCommand(exit);
    setCommandListener(this);
    printCanvasInfo();
  }

  /**
     Paints the look of the Canvas that the user sees.  In
     this case, it "paints" nothing.  Therefore, this
     Canvas has no visual representation because there is
     nothing painted on the screen by this method.
  */
  public void paint(Graphics g) 
  {
    
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == exit)
      CanvasDemo1.getMIDlet().quit();
  }

  /**
     Defines the processing to be done in response to a
     key release event occuring on this Canvas.  This
     method overrides the same method in Canvas.
  */
  public void keyReleased(int keyCode)
  {
    printKeyEventInfo(keyCode);
  }

  /**
     Defines some event handling for key events.  This
     method simply prints to standard output some
     diagnostic information about key events on the
     Canvas.
  */
  protected void printKeyEventInfo(int keyCode)
  {
    System.out.println("Key code = " + 
		       keyCode);
    System.out.println("Key name = " + 
		       getKeyName(keyCode));
    System.out.println("Game action = " + 
		       getGameAction(keyCode));
  }

  /**
     Prints diagnostic information about the Canvas object
     attributes and capabilities.
  */
  protected void printCanvasInfo()
  {
    System.out.println("Device height         = " + 
		       getHeight());
    System.out.println("Device width          =  " + 
		       getWidth());
    System.out.println("Pointer events        = " + 
		       hasPointerEvents());
    System.out.println("Pointer motion events = " + 
		       hasPointerMotionEvents());
    System.out.println("Repeat events         = " + 
		       hasRepeatEvents());
  }
}

