import javax.microedition.midlet.MIDlet;
import javax.microedition.io.StreamConnection;
import javax.microedition.io.Connector;
import java.io.IOException;

/**
   This class implements a client that connects to a
   server. To instantiate this class you must specify the
   server (DNS host name) and the well-known port of the
   desired service. 
*/
public class ClientSocket implements Runnable
{
  public static final String PROTOCOL = "socket";

  // The port of the server's well-known socket.
  private String serverPort;

  // The host name of the server to which to connect.
  private String serverHostName;

  // The URI to the well-known server socket.
  private String serverURI;

  // A connection to the server.
  private StreamConnection streamConn;

  protected ClientSocket()
  {
    super();
  }

  /**
     Public constructor.  You must specify the DNS name of
     the server and the service's port number.

     @param server the DNS name of the machine to which you
     want to connect.

     @param port the port number on server to which to
     connect.

     @throws IOException if the connection to the
     specified server cannot be opened.
  */
  public ClientSocket(String server, String port)
    throws IOException
  {
    this();
    serverHostName = server;
    serverPort = port;

    serverURI = buildServerURI();
    open();
  }

  /**
     Constructor.

     @param uri the fully formed URI of the service to
     which you make a connection request. 

     @throws InvalidArgumentException of the URI is
     malformed.
  */
  public ClientSocket(String uri) 
    throws IOException
  {
    this();
    serverURI = uri;
  }

  /**
     Opens the connection.  After this object is created,
     the connection to the server is not yet open.  You
     must open it explicitly.  This makes the usage model
     for clients more flexible.

     @throws IOException if the connection can't be opened
     for some reason.
  */
  public void open() throws IOException
  {
    streamConn = (StreamConnection) Connector.open(serverURI);
  }

  /**
     Closes the connection to the server. 
  */
  public void close()
  {
    try
      {
	streamConn.close();
      }
    catch (IOException ioe)
      {
	ioe.printStackTrace();
      }
  }

  /**
     Executes the client communication. Starts the client
     sending of requests to the server.  This method
     should be called after the open() method establishes
     the connection.
  */
  public void run()
  {
    // Start communicating with the server. 
    // Send requests, read responses, ....

  }

  private String buildServerURI()
  {
    StringBuffer uri = new StringBuffer(PROTOCOL);

    uri.append("://");
    uri.append(serverHostName);
    uri.append(":");
    uri.append(serverPort);

    return uri.toString();
  }
}

