import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

import java.io.IOException;

/**
   Demonstrates double buffering of graphics context for
   display on a Canvas. 
*/
public class DoubleBufferDemo extends Canvas 
  implements CommandListener
{
  // A constant that represents the color white. 
  private static final int WHITE = 
    0xFF << 16 | 0xFF << 8 | 0xFF;

  private static Command back = 
    new Command("Back", Command.BACK, 1);

  GraphicsDemo gDemo = GraphicsDemo.getInstance();
  private Display display = Display.getDisplay(gDemo);

  // The image object to use to obtain an off-screen
  // Graphics object.
  private Image offscreen;

  // A variable used for determining if the implementation
  // is automatically double buffered.  Holds the value
  // "true" if the implementation automatically does
  // double buffering, "false" otherwise.
  private boolean autoDoubleBuffered = true;

  /**
     No-arg constructor.
  */
  public DoubleBufferDemo()
  {
    super();
    addCommand(back);
    setCommandListener(this);
    display.setCurrent(this);

    if (!isDoubleBuffered())
      {
	// If the implementation doesn't automatically
	// use double buffering, get an Image so we
	// can get an off-screen Graphics from it.
	// This Image is mutable! Its dimensions are the 
	// width and height of this Canvas.
	offscreen = Image.createImage(getWidth(), 
				      getHeight());
	autoDoubleBuffered = false;
      }
  }

  protected void paintClipRect(Graphics g)
  {
    int clipX = g.getClipX();
    int clipY = g.getClipY();
    int clipH = g.getClipHeight();
    int clipW = g.getClipWidth();

    int color = g.getColor();
    g.setColor(WHITE);
    g.fillRect(clipX, clipY, clipW, clipH);

    g.setColor(color);
  }

  public void paint(Graphics g)
  {
    Graphics originalG = null;
    int width = getWidth();
    int height = getHeight();

    if (!autoDoubleBuffered)
      {
	// Save original graphics context and get a new
	// off-screen Graphics from the utility Image.
	originalG = g;
	g = offscreen.getGraphics();

	// Clear the clip rectangle using the new Graphics
	// object.  This way we're using double buffering
	// to clear the Canvas, thereby avoiding
	// flickering.  Clearing the Canvas is drawing
	// like all other drawing operations.
	paintClipRect(g);
      }
    else
      {
	// Clear the Canvas with the original graphics
	// because the implementation does double
	// buffering automatically.
	paintClipRect(g);
      }
    for (int x = 0, y = 0; (x < width / 2); x = x + 2)
      {
	g.drawRect(x, y, (width - x) - x, (height - y) - y);
	y++; y++;
      }

    // Drawing the image actually copies the contents of
    // the image's off-screen Graphics context to the
    // device's Graphics context.
    if (!autoDoubleBuffered)
      {
	originalG.drawImage(offscreen, 0, 0, 
			    Graphics.TOP | Graphics.LEFT);
      }
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == back)
      {
	GraphicsDemo.getInstance().display();
      }
  }
}
