import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

import java.io.IOException;

/**
   Demonstrates double buffering of images on a Canvas.
   Images are automatically double buffered.  This program
   demonstrates that you don't have to do anything to get
   double buffered behavior when displaying images.

   However, you still have to double buffer the operation
   that paints the background of the Canvas before
   painting the image.
*/
public class DoubleBufferImageDemo extends Canvas 
  implements CommandListener
{
  // A constant that represents the color white. 
  private static final int WHITE = 
    0xFF << 16 | 0xFF << 8 | 0xFF;

  private static Command back = 
    new Command("Back", Command.BACK, 1);

  private GraphicsDemo gDemo = GraphicsDemo.getInstance();
  private Display display = Display.getDisplay(gDemo);

  // A reference to the Image this object displays.
  Image image;

  // A variable used for determining if the implementation
  // is automatically double buffered.  Holds the value
  // "true" if the implementation automatically does
  // double buffering, "false" otherwise.
  private boolean autoDoubleBuffered = true;

  /**
     No-arg constructor.  
  */
  public DoubleBufferImageDemo()
  {
    super();

    if (!isDoubleBuffered())
      {
	autoDoubleBuffered = false;
      }
    
    // Create the PNG image.  The image is "drawn" in an
    // immutable Image object, which has its own
    // off-screen Graphics.  We create the image here in
    // the constructor, instead of in the paint() method,
    // so that it's created only once.
    try
      {
	image = Image.createImage("/bottle80x80.png");
      }
    catch (IOException ioe)
      {
	System.out.println(ioe.getMessage());
	ioe.printStackTrace();
      }

    addCommand(back);
    setCommandListener(this);
    display.setCurrent(this);
  }

  protected void paintClipRect(Graphics g)
  {
    int clipX = g.getClipX();
    int clipY = g.getClipY();
    int clipH = g.getClipHeight();
    int clipW = g.getClipWidth();

    int color = g.getColor();
    g.setColor(WHITE);
    g.fillRect(clipX, clipY, clipW, clipH);

    g.setColor(color);
  }

  /**
     Paints an image on this object's visible Canvas.  
  */
  public void paint(Graphics g)
  {
    Graphics originalG = null;
    int width = getWidth();
    int height = getHeight();

    if (image == null)
      {
	return;
      }

    // We still need to double buffer the drawing
    // operations that clear the Canvas graphics.
    if (!autoDoubleBuffered)
      {
	// Save the original graphics context and use the
	// off-screen Graphics from the Image to clear the
	// clip rectangle.
	originalG = g;
	g = image.getGraphics();
	paintClipRect(g);
      }
    else
      {
	// Paint the background with the original Graphics
	// passed in.
	paintClipRect(g);
      }

    // We don't need to double buffer the call to display
    // the Image.  This method call draws the image in the
    // Image object's off-screen Graphics, then copies its
    // contents to the device Graphics context implicitly.
    g.drawImage(image, 0, 0, Graphics.TOP | Graphics.LEFT);
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == back)
      {
	GraphicsDemo.getInstance().display();
      }
  }
}
