import javax.microedition.midlet.MIDlet;
import javax.microedition.lcdui.*;

/**
   Defines the MIDlet that is the launching point for a
   series of graphics drawing demos.  This MIDlet displays
   a list of graphics demos.  The user selects one using
   the device's "select" button.
*/
public class GraphicsDemo extends MIDlet 
  implements CommandListener
{
  private static Command exit = 
    new Command("Exit", Command.EXIT, 1);

  private static String [] demoClasses =
  {
    "LineDemo",
    "RectangleDemo",
    "ArcDemo",
    "TextDemo",
    "TranslationDemo",
    "DoubleBufferDemo",
    "DoubleBufferImageDemo"
  };

  private int lastSelected = 0;

  private static GraphicsDemo instance; 

  private List mainMenu = new List("Select demo", 
				   Choice.IMPLICIT,
				   demoClasses, 
				   null);

  /**
     Constructor.
  */
  public GraphicsDemo()
  {
    super();
    instance = this;
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  public static GraphicsDemo getInstance()
  {
    return instance;
  }

  public void display()
  {
    mainMenu.setSelectedIndex(lastSelected, true);
    Display.getDisplay(this).setCurrent(mainMenu);
  }

  public void startApp()
  {
    Display display;  

    mainMenu.addCommand(exit);
    mainMenu.setCommandListener(this);
    mainMenu.setSelectedIndex(lastSelected, true);

    display = Display.getDisplay(this);
    display.setCurrent(mainMenu);
  }

  public void pauseApp()
  {

  }

  public void quit()
  {
    destroyApp(true);
    notifyDestroyed();
  }

  public void destroyApp(boolean destroy)
  {
    mainMenu = null;
  }

  public void commandAction(Command c, Displayable d)
  {
    Displayable displayable = null;

    if (c == List.SELECT_COMMAND)
      {
	int index = mainMenu.getSelectedIndex();
	lastSelected = index;
	String demoClassName = demoClasses[index];
	try
	  {
	    displayable = (Displayable) 
	      Class.forName(demoClasses[index]).newInstance();
	    Display.getDisplay(this).setCurrent(displayable);
	  }
	catch (Exception e)
	  {
	    e.printStackTrace();
	    return;
	  }
      }
    else if (c == exit)
      {
	quit();
      }
  }
  

}
