import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;

/**
   This class defines a Form that displays some
   simple text and a menu of commands.  The purpose
   of this class is to demonstrate i18n and l10n of
   the user visible attributes.  The class retrieves
   l10n resources from the application management
   software.
*/
public class HelloForm extends Form
{
  // The default title of this Form. 
  private static final String DEFAULT_TITLE = 
    "Hello, World";

  // The command listener that handles command
  // events on this Form.
  private MyCommandListener cl = new 
    MyCommandListener();

  // The display instance associated with this
  // MIDlet.
  Display display;

  // A reference to this object's associated MIDlet
  // object.
  I18NDemo midlet;

  // An alert displayed in response to the
  // activation of some of this Form's commands.
  Alert alert;

  // The commands that are placed on this form. 
  private Command showAlert; 
  private Command sayHi;
  private Command cancel;
  private Command exit;
  private Command help;
  private Command item;
  private Command ok;
  private Command screen;
  private Command stop;

  /**
     No-arg constructor.  Sets a default title for
     the form.
  */
  HelloForm()
  {
    this(DEFAULT_TITLE);
  }

  /**
     Constructor.

     @param title the title of the Form.
  */
  HelloForm(String title)
  {
    super(title);

    midlet = I18NDemo.getInstance();

    // Add a string widget to the form.  
    String msg = midlet.getResource("greeting");
    append(msg);

    display = Display.getDisplay(midlet);

    // Add a MyCommandListener to the Form to listen
    // for the "Back" key press event, which should
    // make an Alert dialog pop up.
    setCommandListener(cl);

    showAlert = new
      Command(midlet.getResource("alert"), 
	      Command.SCREEN, 1);
    addCommand(showAlert);

    sayHi = new
      Command(midlet.getResource("sayhi"), 
	      Command.SCREEN, 1);
    addCommand(sayHi);

    cancel = new
      Command(midlet.getResource("cancel"), 
	      Command.SCREEN, 1);
    addCommand(cancel);

    exit = new
      Command(midlet.getResource("exit"), 
	      Command.SCREEN, 1);
    addCommand(exit);

    help = new
      Command(midlet.getResource("help"), 
	      Command.SCREEN, 1);
    addCommand(help);

    item = new
      Command(midlet.getResource("item"),
	      Command.SCREEN, 1);
    addCommand(item);

    ok = new
      Command(midlet.getResource("ok"), 
	      Command.SCREEN, 1);
    addCommand(ok);

    screen = new
      Command(midlet.getResource("screen"), 
	      Command.SCREEN, 1);
    addCommand(screen);

    stop = new
      Command(midlet.getResource("stop"), 
	      Command.SCREEN, 1);
    addCommand(stop);
  }

  // This class simply listens for any command
  // activation.  The HelloForm instance sets an
  // instance of this class as its command listener.
  // The object instance doesn't check the command
  // information, but simply displays a modal Alert
  // indicating a soft button was activated by the
  // user.
  private class MyCommandListener 
    implements CommandListener
  {
    public void commandAction(Command c, 
			      Displayable d)
    {
      String title = 
	midlet.getResource("alert_title");
      String msg = null;

      if (c == showAlert)
	{
	  msg = midlet.getResource("alert_text");
	  alert = new Alert(title, 
			    msg,
			    null, AlertType.INFO);
	  alert.setTimeout(Alert.FOREVER);
	  display.setCurrent(alert, HelloForm.this);
	}
      else if (c == sayHi)
	{
	  alert = new Alert("Button pressed",
			    msg,
			    null, AlertType.INFO);
	  alert.setTimeout(Alert.FOREVER);
	  display.setCurrent(alert, HelloForm.this);
	}

      if (c == exit)
	{
	  I18NDemo.getInstance().destroyApp(true);
	}
    }
  }
}
