import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;

/**
   This class defines a Form that displays some
   simple text and a menu of commands.  The purpose
   of this class is to demonstrate
   internationalization and localization of the
   user-visible attributes.

   <p>This version works in conjunction with
   I18NDemo3.  It retrieves l10n resources from the
   resource bundle initialized by the I18NDemo
   class.
*/
public class HelloForm3 extends Form
{
  // The default title of this Form. 
  private static final String DEFAULT_TITLE = 
    "Hello, World";

  // The command listener that handles command
  // events on this Form.
  private MyCommandListener cl = new 
    MyCommandListener();

  // The display instance associated with this
  // MIDlet.
  Display display;

  // A reference to the resource bundle created by
  // the MIDlet.
  ListResourceBundle bundle;

  // An alert displayed in response to the
  // activation of some of this Form's commands.
  Alert alert;

  private Command showAlert; 
  private Command sayHi;
  private Command cancel;
  private Command exit;
  private Command help;
  private Command item;
  private Command ok;
  private Command screen;
  private Command stop;

  /**
     No-arg constructor.  Sets a default title for
     the form.
  */
  HelloForm3()
  {
    this(DEFAULT_TITLE);
  }

  /**
     Constructor.

     @param title the title of the Form.
  */
  HelloForm3(String title)
  {
    super(title);

    bundle = I18NDemo3.getResourceBundle();
    try
      {
	// Add a string widget to the form.  
	String msg = (String) 
	  bundle.getObject("greeting");
	append(msg);

	display = Display.
	  getDisplay(I18NDemo3.getInstance());

	// Add a MyCommandListener to the Form to
	// listen for the "Back" key press event,
	// which should make an Alert dialog pop up.
	setCommandListener(cl);

	showAlert = new
	  Command((String) bundle.getObject("alert"),
		  Command.SCREEN, 1);
	addCommand(showAlert);

	sayHi = new
	  Command((String) bundle.getObject("sayhi"), 
		  Command.SCREEN, 1);
	addCommand(sayHi);

	cancel = new
	  Command((String) bundle.getObject("cancel"),
		  Command.SCREEN, 1);
	addCommand(cancel);

	exit = new
	  Command((String) bundle.getObject("exit"), 
		  Command.SCREEN, 1);
	addCommand(exit);

	help = new
	  Command((String) bundle.getObject("help"), 
		  Command.SCREEN, 1);
	addCommand(help);

	item = new
	  Command((String) bundle.getObject("item"), 
		  Command.SCREEN, 1);
	addCommand(item);

	ok = new
	  Command((String) bundle.getObject("ok"), 
		  Command.SCREEN, 1);
	addCommand(ok);

	screen = new
	  Command((String) bundle.getObject("screen"), 
		  Command.SCREEN, 1);
	addCommand(screen);

	stop = new
	  Command((String) bundle.getObject("stop"), 
		  Command.SCREEN, 1);
	addCommand(stop);
      }
    catch (MissingResourceException mre)
      {
	mre.printStackTrace();
      }
  }

  // This class simply listens for any command
  // activation.  The HelloForm instance sets an
  // instance of this class as its command listener.
  // The object instance doesn't check the command
  // information, but simply displays a modal Alert
  // indicating a soft button was activated by the
  // user.
  private class MyCommandListener 
    implements CommandListener
  {
    public void commandAction(Command c, 
			      Displayable d)
    {
      try
	{
	  String title = (String) 
	    bundle.getObject("alert_title");
	  String msg = (String) 
	    bundle.getObject("alert_text");

	  if (c == showAlert)
	    {
	      alert = new Alert(title, 
				msg,
				null, AlertType.INFO);
	      alert.setTimeout(Alert.FOREVER);
	      display.setCurrent(alert, HelloForm3.this);
	    }
	  else if (c == sayHi)
	    {
	      alert = new Alert(title,
				msg,
				null, AlertType.INFO);
	      alert.setTimeout(Alert.FOREVER);
	      display.setCurrent(alert, HelloForm3.this);
	    }

	  if (c == exit)
	    {
	      I18NDemo3.getInstance().quit();
	    }
	}
      catch (MissingResourceException mre)
	{

	}
    }
  }
}
