import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;

/**
  The first version of the I18NDemo application.  

  <p>This version demonstrates a naive approach of
  loading localized resources from the MIDlet JAD
  file.  This approach quickly becomes untenable for
  large numbers of resources.  And it's only useful
  for text messaging, not other kinds of localized
  resources.
*/
public class I18NDemo extends MIDlet
{
  // The locale specified for the execution of this
  // MIDlet.
  private String locale;

  // The Displayable.  This component is displayed
  // on the screen.
  private HelloForm form;

  // The Display instance.  This object manages all
  // Displayable components for this MIDlet.
  private Display display;

  // An instance of the MIDlet.
  private static I18NDemo instance; 

  // The prefix for the attribute names of localized
  // resources.
  String attrPrefix = new String("I18NDemo-");

  /**
     No-arg constructor.
  */
  public I18NDemo()
  {
    super();
    instance = this;
  }

  /**
     Gets the instance of this class that exists in
     the running application.

     @return the instance created when the
     application starts up.
  */
  public static I18NDemo getInstance()
  {
    if (instance == null)
      {
	instance = new I18NDemo();
      }
    return instance;
  }

  /**
     Start the MIDlet.  Get the current locale for
     the implementation.  Use it to construct a
     prefix for attribute keys for all localized
     resources.  The names of the localized
     resources in the JAD file follow a compatible
     naming scheme.
  */
  public void startApp()
  {
    // Retrieve the locale from the AMS software.
    // The locale must be set before this MIDlet
    // executes.
    locale = 
      System.getProperty("microedition.locale");

    // Create a Displayable widget.  Get the
    // localized String that represents the title of
    // the Form from the JAD file user-defined
    // attributes.  Get all localized strings in
    // this way.
    String formTitle = getResource("title");
    form = new HelloForm(formTitle);

    // This app simply displays the single form
    // created above.
    display = Display.getDisplay(this);
    display.setCurrent(form);
  }

  /**
     Returns the value associated with the specified
     key from the list of user-defined MIDlet
     resources in the application JAD file.

     @param key the key of the key-value pair.

     @returns the value associated with the
     specified key.
  */
  public String getResource(String key)
  {
    StringBuffer index = new 
      StringBuffer(attrPrefix);
    String value; 

    index.append(key);
    index.append('-');
    index.append(locale);

    value = getAppProperty(index.toString());
    return value;
  }

  /**
     Quit the application.  Notify the
     implementation that we are quitting.
  */
  public void quit()
  {
    notifyDestroyed();
  }

  public void destroyApp(boolean destroy)
  {

  }
    
  public void pauseApp()
  {

  }
}


