import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;

import java.util.Hashtable;

/**
  The third version of the I18NDemo application.  

  <p>This version of I18NDemo uses a resource bundle to
  define localized resources.  The application determines
  the platform's current locale, and attempts to load the
  associated bundle containing the correct localized
  resources.  If it can't find those resources, it loads
  the U.S. English resources, represented by the en_US
  language and country designation.

  <p>This approach is the most desirable.  Localized
  resources other than strings can easily be supported.
*/
public class I18NDemo3 extends MIDlet
{
  // The locale specified for the execution of this
  // MIDlet.
  private String locale;

  // The resource bundle that holds the localized
  // resources for the execution of this application.
  private static ResourceBundle bundle;

  // The Displayable.  This component is displayed on the
  // screen.
  private HelloForm3 form;

  // The Display instance.  This object manages all
  // Displayable components for this MIDlet.
  private Display display;

  // An instance of the MIDlet.
  private static I18NDemo3 instance; 

  /**
     No-arg constructor.
  */
  public I18NDemo3()
  {
    super();
    instance = this;
  }

  /**
     Gets the instance of this class that exists in the
     running application.

     @return the instance created when the application
     starts up.
  */
  public static I18NDemo3 getInstance()
  {
    if (instance == null)
      {
	instance = new I18NDemo3();
      }
    return instance;
  }

  /**
     Gets the resource bundle used by this MIDlet.  This
     method is useful for other classes that need access
     to the application's localized resources.

     @returns the MIDlet's localized resources. 
  */
  public static ListResourceBundle getResourceBundle()
  {
    return (ListResourceBundle) bundle;
  }

  /**
     Starts the MIDlet.  Determines the current locale of
     the execution environment and uses it to construct
     the name of a resource bundle of localized resources.
     Uses this name to build the name of a Java class that
     is then loaded using Class.  If there is no matching
     resource bundle, the default U.S. English resource
     bundle is used.
  */
  public void startApp()
  {
    // Retrieve the locale from the AMS software.  The
    // locale must be set before this MIDlet executes.
    locale = System.getProperty("microedition.locale");
    //    locale = "hy_AM";
    locale = "zh_CN";

    bundle = null;
    try
      {
	bundle = 
	  ResourceBundle.getBundle("I18NDemoResources",
				   locale);
	if (bundle == null)
	  {
	    bundle = 
	      ResourceBundle.getBundle("I18NDemoResources",
				       "en_US");
	  }
      }
    catch (MissingResourceException mre)
      {
	mre.printStackTrace();
      }

    try
      {
	// Create a Displayable widget.  Get the localized
	// String that represents the title of the Form.
	String formTitle = (String) 
	  bundle.getObject("title");
	form = new HelloForm3(formTitle);
      }
    catch (MissingResourceException mre)
      {
	mre.printStackTrace();
      }

    // This app simply displays the single form created
    // above.
    display = Display.getDisplay(this);
    display.setCurrent(form);
  }

  /**
     Returns the value associated with the specified key
     from the list of user-defined MIDlet resources in the
     application JAD file.

     @param key the key of the key-value pair.

     @returns the value associated with the specified key.
  */
  public Object getResource(String key)
  {
    Object resource = null;

    try
      {
	resource = bundle.getObject(key);
      }
    catch (MissingResourceException mre)
      {

      }
    return resource;
  }

  /**
     Quit the MIDlet.  Notify the implementation that it
     can destroy all application resources.  The
     implementation will call destroyApp().
  */
  public void quit()
  {
    notifyDestroyed();
  }

  public void destroyApp(boolean destroy)
  {

  }
    
  public void pauseApp()
  {

  }
}
