/**
   This class defines a resource bundle as a convenient
   array of resources.  It mimics the class of the same
   name defined by the J2SE platform,
   java.util.ListResourceBundle.

   <p>This class is abstract.  Applications are forced to
   subclass it and define concrete classes that contain
   localized resources.

   <p>Concrete application specific subclasses should be
   named so that the name contains the language and
   country designation according to the ISO 639 and ISO
   3166 standards for languages and country codes,
   respectively.
*/
public abstract class ListResourceBundle 
  extends ResourceBundle
{
  /**
     No-arg constructor. 
  */
  public ListResourceBundle()
  {
    super();
  }

  // The array of resources in key-value format. 
  private static final Object [][] contents = null;

  /**
     Gets the array of resources.

     @returns the two-dimensional array of key-value
     pairs that this bundle defines.
  */
  public abstract Object [][] getContents();

  /**
     Gets the object that represents the value associated
     with the specified key.

     @param key the key of the key-value pair.
     @returns the object that represents the value of a
     key-value pair.
  */
  public final Object handleGetObject(String key)
  {
    Object value = null;

    if (key == null)
      {
	return null;
      }
    Object [][] pairs = getContents();

    for (int i = 0; i < pairs.length; i++)
      {
	if (key.equals(pairs[i][0]))
	  {
	    value = (pairs[i][1]);
	  }
      }
    return value;
  }
}
