import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.List;

import javax.microedition.rms.RecordEnumeration;
import javax.microedition.rms.RecordStore;
import javax.microedition.rms.RecordStoreException;

import java.io.ByteArrayInputStream;
import java.io.DataInputStream;
import java.io.IOException;

/**
   This class is a UI component that displays a list of
   records found in the record store.  It uses the
   AddressBook object defined by the MIDlet class for this
   MIDlet application.

   @see AddressBook
   @see AddressBookMain
*/
public class RecordList extends List 
  implements CommandListener
{
  private static Command go = 
    new Command("Go", Command.SCREEN, 1);

  private static Command back =
    new Command("Back", Command.BACK, 1);

  private Display display;
  private static RecordList instance; 

  /**
     Constructor.

     @param title the title of the UI screen, which is a
     List.
  */
  public RecordList(String title) 
  {
    super(title, List.IMPLICIT);
    instance = this;
    PersistenceDemo pDemo = PersistenceDemo.getInstance();
    display = Display.getDisplay(pDemo);

    addCommand(back);
    setCommandListener(this);

    if (buildRecordList() <= 0)
      setTitle("No records found");
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  public static RecordList getInstance()
  {
    return instance;
  }

  void display()
  {
    display.setCurrent(this);
  }

  /**
     Builds a list of the records in the record store.
     Returns the number of records found.  This method
     retrieves all records from the record store; that is,
     it uses no filters to retrieve records.  Neither does
     it use any record comparators, so it doesn't order
     the records returned.

     <p>This method throws no exceptions, but catches any
     exceptions that occur accessing the record store.

     @return the number of records found in the record
     store, or 0 if no records are found. 
  */
  int buildRecordList()
  {
    AddressBook addressBook = 
      AddressBookMain.getInstance().getAddressBook();
    RecordStore recordStore = addressBook.getRecordStore();

    int numRecords = 0;
    try
      {
	RecordEnumeration re;

	re = recordStore.enumerateRecords(null, null, false);
	if (re.numRecords() > 0)
	  {
	    ByteArrayInputStream bais = null;
	    DataInputStream dis = null;
	    String name = null;
	    while (re.hasNextElement())
	      {
		byte [] record = re.nextRecord();

		bais = new ByteArrayInputStream(record);
		dis = new DataInputStream(bais);

		String strRec = new String(record);
		name = dis.readUTF();
		append(name, null);
		numRecords++;
	      }
	  }
	else
	  {
	    Alert a = 
	      new Alert("No records", 
			"No records found in record store",
			null,
			AlertType.CONFIRMATION);
	    a.setTimeout(Alert.FOREVER);
	    display.setCurrent(a, AddressBookMain.getInstance());
	  }
      }
    catch (RecordStoreException re)
      {
	re.printStackTrace();
	Alert a = new Alert("Error retrieving record", 
			    "Error retrieving record.",
			    null,
			    AlertType.CONFIRMATION);
	a.setTimeout(Alert.FOREVER);
	display.setCurrent(a, this);
      }
    catch (IOException ioe)
      {
	ioe.printStackTrace();
      }
    finally
      {
	return numRecords;
      }
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == back)
      {
	AddressBookMain.getInstance().display();
      }
  }
}

