import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Form;
import javax.microedition.lcdui.Displayable;

/**
   This class defines the Form that displays the
   meta-information describing the HTTP resource. It is
   designed to be controlled by a separate thread, hence
   it implements Runnable. 

   This Form object uses a helper object to communicate
   over the Connection with the HTTP resource. It then
   takes the connection data from the helper object to
   display on the screen for the user.
*/
public class ResourceDisplay extends Form
  implements CommandListener, Runnable
{
  private static Command back = 
    new Command("Back", Command.BACK, 1);

  private static Displayable instance; 

  // The helper object that makes the actual connection to
  // the resource on the origin server and fetches the
  // resource's meta-information.
  //
  private HttpResource resource; 

  /**
     Constructor.

     @param uri the URI of the resource to fetch via a
     HTTP protocol request.
  */
  public ResourceDisplay(String uri)
  {
    super("Http Info");
    instance = this;
    resource = new HttpResource(uri);

    addCommand(back);
    setCommandListener(this);
  }

  /**
     Starts the execution of this object: runs the
     HttpResource helper object.

     @see HttpResource
  */
  public void run()
  {
    resource.run();
    append(resource.getResourceMetaInfo());
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  public static Displayable getInstance()
  {
    return instance;
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == back)
      {
	URIEntry.getInstance().display();
      }
  }
}

