import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;
import javax.microedition.lcdui.TextField;

import javax.microedition.rms.RecordEnumeration;
import javax.microedition.rms.RecordStoreException;

import java.util.Enumeration;
import java.util.Vector;

/**
   This class implements the screen that enables the user
   to search for one or more particular records in the
   address book.  The user enters a name or prefix that
   represents the name of one or more records in the
   address book.
*/
public class SearchScreen extends Form 
  implements CommandListener
{
  private static Command go = 
    new Command("Go", Command.SCREEN, 1);

  private static Command back = 
    new Command("Back", Command.BACK, 1);

  private static SearchScreen instance;
  private Display display;

  private AddressBookMain addressBook; 
  private TextField keyEntry;

  /**
     Constructor.
  */
  public SearchScreen()
  {
    super("Search for entry");
    instance = this;
    PersistenceDemo pDemo = PersistenceDemo.getInstance();
    display = Display.getDisplay(pDemo);
    addressBook = AddressBookMain.getInstance();

    keyEntry = new TextField("Enter name", 
			     null, 
			     20, 
			     TextField.ANY);
    append(keyEntry);

    addCommand(go);
    addCommand(back);
    setCommandListener(this);
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  public static SearchScreen getInstance()
  {
    return instance;
  }

  void display()
  {
    display.setCurrent(this);
  }

  /**
     Displays the data passed to it on screen.  Actually
     this method delegates the job of displaying the data
     to an instance of SearchResultScreen.  This method,
     however, sets a new instance of that class to be the
     current displayable.

     @param results a Vector of records from the address
     book's record store.  
  */
  void displaySearchResults(Vector results)
  {
    SearchResultScreen screen = 
      new SearchResultScreen(results);
    display.setCurrent(screen);
  }

  /**
     Builds a result set of records that match a specified
     name.  The criteria is that the record must match the
     name entered by the user in the "keyEntry" TextField.
     This method employs the
     AddressBook.getMatchesByName() method to apply the
     specific filter that defines this name matching.
  */
  Vector buildSearchResults()
  {
    AddressBook addressBook = 
      AddressBookMain.getInstance().getAddressBook();

    String matchKey = keyEntry.getString();
    Vector results = new Vector();

    try
      {
	RecordEnumeration re = 
	  addressBook.getMatchesByName(matchKey);
	byte [] record = null;

	while (re.hasNextElement())
	  {
	    record = re.nextRecord();
	    results.addElement(record);
	  }
      }
    catch (RecordStoreException rse)
      {
	rse.printStackTrace();
      }	
    return results;
  }
  
  /**
     Builds search results and displays it on the screen.
  */
  class BuildSearchResultsAction implements Runnable
  {
    public void run()
    {
      Vector results = buildSearchResults();
      displaySearchResults(results);
    }
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == go)
      {
	Runnable action = new BuildSearchResultsAction();
	action.run();
      }
    else if (c == back)
      {
	AddressBookMain.getInstance().display();
      }
  }
}


