import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Choice;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.List;

/**
   Demonstrates the use of the MIDP UI high-level
   components.  This demo class builds a list of demos for
   the user to select.  It then runs the demo upon
   selection.
*/
public class UIComponentDemo extends MIDlet 
  implements CommandListener
{
  private Command exit = 
    new Command("Exit", Command.EXIT, 1);

  // The names of the various demo programs.  The items in
  // this list are the names of the primary classes for
  // each demo.
  private static String [] demos =
  {
    "AlertDemo",
    "DateFieldDemo",
    "GaugeDemo",
    "StringItemDemo",
    "TickerDemo",
    "ImageItemDemo"
  };

  private static UIComponentDemo instance = null; 

  // The actual List component that displays the items in
  // the "demos" list above. 
  private List mainMenu = new List("Select demo", 
				   Choice.IMPLICIT, 
				   demos, null);

  /**
     Constructor.
  */
  public UIComponentDemo()
  {
    // Notice the call to super().  This executes the
    // no-arg constructor in the MIDlet class.
    super();
    instance = this;
  }

  /**
     Returns the single instance of this class.  Calling
     this method before constructing an object will return
     a null pointer.
     
     @return an instance of this class.
  */
  public static UIComponentDemo getInstance()
  {
    return instance;
  }

  public void startApp()
  {
    Display display;  

    mainMenu.addCommand(exit);
    mainMenu.setCommandListener(this);

    display = Display.getDisplay(this);
    display.setCurrent(mainMenu);
  }

  public void pauseApp()
  {

  }

  void quit()
  {
    destroyApp(true);
    notifyDestroyed();
  }

  public void destroyApp(boolean destroy)
  {

  }

  /**
     Sets this object to be the current displayable object
     for the MIDlet.
  */
  public void display()
  {
    Display.getDisplay(this).setCurrent(mainMenu);
  }

  public void commandAction(Command c, Displayable d)
  {
    Displayable displayable = null;

    if (c == List.SELECT_COMMAND)
      {
	int index = mainMenu.getSelectedIndex();
	try
	  {
	    displayable = (Displayable) 
	      Class.forName(demos[index]).newInstance();
	    if (displayable == null)
	      {
		return;
	      }
	    Display display = Display.getDisplay(this);
	    display.setCurrent(displayable);
	  }
	catch (Exception e)
	  {
	    System.out.println("Got an exception here!!!");
	    e.printStackTrace();
	    return;
	  }
      }
    else if (c == exit)
      {
	quit();
      }
  }
}

