import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;
import javax.microedition.lcdui.TextField;

/**
   This class defines the Form that prompts the user for a
   URI to which the HTTP connection will be made. The user
   enters the URI and hits the "Go" command button. 

   This class's instance then instantiates the helper
   ResourceDisplay class, which does the job of fetching
   the HTTP resource and displaying it.
*/
public class URIEntry extends Form
  implements CommandListener
{
  private static Command go = 
    new Command("Go", Command.SCREEN, 1);

  private static Command exit = 
    new Command("Exit", Command.EXIT, 1);

  private static URIEntry instance;

  // The URI entered by the user.
  private TextField uri; 

  // The thread that controls execution of the
  // ResourceDisplay object.
  private Thread thread;

  /**
     Constructor.

     @param title the title of the Form.
  */
  private URIEntry(String title)
  {
    super(title);
    instance = this;

    uri = new TextField("Connect to:", 
			null, 
			70, 
			TextField.URL);
    uri.setString("http://");

    append(uri);

    addCommand(go);
    addCommand(exit);
    setCommandListener(this);
  }

  /**
     Returns the single instance of this class.
     
     @return an instance of this class.
  */
  public static URIEntry getInstance()
  {
    if (instance == null)
      {
	instance = new URIEntry("Enter URL");
      }
    return instance;
  }

  /**
     Sets this object to be the current displayable object
     for the MIDlet.
  */
  public void display()
  {
    MIDlet m = ConnectionDemo.getInstance();
    Display.getDisplay(m).setCurrent(this);
  }

  public void commandAction(Command c, Displayable d)
  {
    if (c == go)
      {
	// This screen displays the meta-information of
	// the resource specified by the URI.  
	ResourceDisplay view = 
	  new ResourceDisplay(uri.getString());

	MIDlet m = ConnectionDemo.getInstance();
	Display.getDisplay(m).setCurrent(view);

	thread = new Thread(view);
	thread.start();
      }
    else if (c == exit)
      {
	ConnectionDemo.getInstance().quit();
      }
  }
}
